@@ -1,4 +1,3 @@
-#include <memory>
 #include <QMessageBox>
 #include <QDir>
 #include <QPluginLoader>
@@ -11,21 +10,19 @@
 
 const std::vector<QString> MainWindow::PLUGINS_DIRS = {"/usr/lib/kaukkis/plugins", "plugins"};
 
-//Doesn't compile without this even with "std::" additions... go figure
-using namespace std;
 //FIXME: IconView in maemo
-//FIXME: Portrait->landscape buttons get lost
-//TODO: Detect keyboard out
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::MainWindow),
-    pluginsDialog_(new PluginDialog(this))
+    pluginsDialog_(new PluginDialog(this)),
+    themeDialog_(new ThemeDialog(this))
 {
     ui->setupUi(this);
 
     loadOutputPlugins();
-    //TODO: Choose first one from all themes
+    //TODO: Choose first one from all remotes
     Remote* remote = new Remote("default", this);
+    themeDialog_->setActiveRemote(remote);
     ui->graphicsView->setScene(remote);
     ui->graphicsView->setDragMode(QGraphicsView::ScrollHandDrag);
     setupHildonMenu();
@@ -92,14 +89,14 @@ void MainWindow::landscapeMode()
 std::vector<IRemoteOutput*> MainWindow::remoteOutputs() const
 {
     return remoteOutputs_;
+    //std::vector<IRemoteOutput*> rVal;
+    //for (const auto& ptr : remoteOutputs2_)
+    //{
+    //    rVal.push_back(ptr.get());
+    //}
+    //return rVal;
 }
 
-void MainWindow::setRemoteOutputs(const std::vector<IRemoteOutput*>& remoteOutputs)
-{
-    remoteOutputs_ = remoteOutputs;
-}
-
-
 void MainWindow::addUseModeActions()
 {
     ui->graphicsView->setBackgroundBrush(QBrush(Qt::NoBrush));
@@ -107,6 +104,7 @@ void MainWindow::addUseModeActions()
     ui->menubar->removeAction(ui->actionAddButton);
     ui->menubar->removeAction(ui->actionSave);
     ui->menubar->removeAction(ui->actionPlugins);
+    ui->menubar->removeAction(ui->actionThemes);
 }
 
 void MainWindow::useMode()
@@ -122,6 +120,7 @@ void MainWindow::editMode()
     ui->menubar->addAction(ui->actionAddButton);
     ui->menubar->addAction(ui->actionSave);
     ui->menubar->addAction(ui->actionPlugins);
+    ui->menubar->addAction(ui->actionThemes);
     activeRemote()->editMode();
 }
 
@@ -170,6 +169,7 @@ void MainWindow::loadOutputPlugins()
                         if (rVal.second)
                         {
                             qDebug() << "MainWindow: Loaded " << newRemoteOutput->name() << " plugin.";
+                            //remoteOutputs2_.push_back(std::unique_ptr<IRemoteOutput>(newRemoteOutput));
                             remoteOutputs_.push_back(newRemoteOutput);
                         }
                         else
@@ -218,6 +218,7 @@ void MainWindow::setupHildonMenu()
     connect(ui->actionAbout, SIGNAL(triggered()), this, SLOT(showAbout()));
     connect(ui->actionAutoOrientation, SIGNAL(triggered()), this, SLOT(autoOrientation()));
     connect(ui->actionPlugins, SIGNAL(triggered()), pluginsDialog_, SLOT(show()));
+    connect(ui->actionThemes, SIGNAL(triggered()), themeDialog_, SLOT(show()));
     //Use mode is the default mode
     addUseModeActions();
 }
