@@ -2,13 +2,13 @@
 #define MAINWINDOW_H
 
 #include <vector>
-#include <memory>
 #include <QGraphicsView>
 #include <QMainWindow>
 #include <QSettings>
 #include "remote.h"
 #include "iremoteoutput.h"
 #include "plugindialog.h"
+#include "themedialog.h"
 
 namespace Ui {
 class MainWindow;
@@ -41,9 +41,7 @@ public:
     Remote* activeRemote() const;
     void loadOutputPlugins();
     std::vector<ButtonAction> avaibleButtonActions() const;
-
     std::vector<IRemoteOutput*> remoteOutputs() const;
-    void setRemoteOutputs(const std::vector<IRemoteOutput*>& remoteOutputs);
 
 private slots:
     void useMode();
@@ -58,6 +56,9 @@ private:
 
     Ui::MainWindow* ui;
     PluginDialog* pluginsDialog_;
+    ThemeDialog* themeDialog_;
+    //Use of unique_ptr causes double free error in destructor.
+    //std::vector<std::unique_ptr<IRemoteOutput>> remoteOutputs_;
     std::vector<IRemoteOutput*> remoteOutputs_;
 
     void setupHildonMenu();
