@@ -5,16 +5,17 @@
 #include <QString>
 #include <QSignalMapper>
 #include <QDialog>
-#include "networkoutput_global.h"
-#include "iremoteoutput.h"
-#include "buttonaction.h"
+#include <QSettings>
+#include <QtCore/qplugin.h>
+#include "../../iremoteoutput.h"
+#include "../../buttonaction.h"
 #include "client.h"
 
 namespace Ui {
     class NetworkOutputDialog;
 }
 
-class NETWORKOUTPUTSHARED_EXPORT NetworkOutput : public QObject, public IRemoteOutput
+class NetworkOutput : public QObject, IRemoteOutput
 {
 
     Q_OBJECT
